***************
Release history
***************

.. This extra heading is here to add an extra layer of depth to the TOC, so that
   all the date headings don't end up filling up the sidebar toc tree
   TODO: there must be a cleaner way to do this

Changelog
#########

.. include:: ../CHANGES.rst
   :start-line: 2
